The Dormouse's Story

# Mad Tea Party

> There was a table set out under a tree in front of the house, and the March Hare and the Hatter were having tea at it: a Dormouse was sitting between them, fast asleep, and the other two were using it as a cushion, resting their elbows on it, and talking over its head. "Very uncomfortable for the Dormouse," thought Alice; "only, as it's asleep, I suppose it doesn't mind."

    The table was a large one, but the three were all crowded together at one corner
      of it: "No room! No room!" they cried out when they saw Alice coming. "There's
      plenty of room!" said Alice indignantly, and she sat down in a large arm-chair
    at one end of the table.

Once upon a time there were three little sisters; and their names were: Elsie, Lacie, and Tillie; and they lived at the bottom of a well.

"What did they live on?" said Alice, who always took a great interest in questions of eating and drinking.

"They lived on treacle," said the Dormouse, after thinking a minute or two.

"They couldn't have done that, you know," Alice gently remarked;
"they'd have been `ill`."

"So they were," said the Dormouse; "very `ill`."

Alice | Hatter | March Hare | Dormouse
Riddle |  | Tea |
| Time |  | Sleep

- Late
- Later
  1. More
  2. Less
- Latest

Raven
  Writing desk.
Water-well
Treacle-well